@@ -49,13 +49,11 @@ struct _ClearlooksStyle
 
 	ClearlooksStyles style;
 	
-	guint8   progressbarstyle;
 	guint8   menubarstyle;
-	guint8   menuitemstyle;
-	guint8   listviewitemstyle;
 	GdkColor scrollbar_color;
 	gboolean has_scrollbar_color;
 	gboolean animation;
+	gfloat   radius;
 };
 
 struct _ClearlooksStyleClass
